#ifndef OBGTK_MENU_SHELL_H
#define OBGTK_MENU_SHELL_H 1

#include <obgtk/obgtkContainer.h>
#include <obgtk/obgtkWidget.h>
#include <obgtk/obgtkMenuItem.h>

@class Gtk_MenuItem;

@interface Gtk_MenuShell : Gtk_Container
{
@public
  GtkMenuShell *gtkmenushell;
}
- castGtkMenuShell:(GtkMenuShell *) castitem;
- appendMenuItem:(Gtk_MenuItem *) child;
- prependMenuItem:(Gtk_MenuItem *) child;
- insertMenuItem:(Gtk_MenuItem *) child
	    aPos:(gint) position;
- deactivate;
@end

#endif /* OBGTK_MENU_SHELL_H */
